# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

from unittest import TestCase

from traitlets import TraitError

from ipywidgets.widgets import Accordion, HTML


class TestAccordion(TestCase):

    def setUp(self):
        self.children = [HTML('0'), HTML('1')]

    def test_selected_index_none(self):
        accordion = Accordion(self.children, selected_index=None)
        state = accordion.get_state()
        assert state['selected_index'] is None

    def test_selected_index(self):
        accordion = Accordion(self.children, selected_index=1)
        state = accordion.get_state()
        assert state['selected_index'] == 1

    def test_selected_index_out_of_bounds(self):
        with self.assertRaises(TraitError):
            Accordion(self.children, selected_index=-1)



# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

"""Contains the Style class"""

from traitlets import Unicode
from .widget import Widget
from .._version import __jupyter_widgets_base_version__

class Style(Widget):
    """Style specification"""

    _model_name = Unicode('StyleModel').tag(sync=True)
    _view_name = Unicode('StyleView').tag(sync=True)
    _view_module = Unicode('@jupyter-widgets/base').tag(sync=True)
    _view_module_version = Unicode(__jupyter_widgets_base_version__).tag(sync=True)
